#
# spec file for package libteam
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libteam
Version:        1.21
Release:        5.4
Summary:        Utilities for controlling 802.1AX team network device
License:        LGPL-2.1+
Group:          System/Kernel
Url:            http://libteam.org/

#Git-Web:	https://github.com/jpirko/libteam
#Git-Clone:	git://github.com/jpirko/libteam
Source0:        http://libteam.org/files/%name-%version.tar.gz
Source1:        %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         /usr/sbin/useradd /usr/sbin/groupadd /usr/sbin/usermod
PreReq:         /bin/sed /bin/awk /bin/grep
BuildRequires:  doxygen
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libdaemon)
BuildRequires:  pkgconfig(libnl-3.0) >= 3.2.0
BuildRequires:  pkgconfig(libnl-cli-3.0) >= 3.2.0
BuildRequires:  pkgconfig(libnl-genl-3.0) >= 3.2.0
BuildRequires:  pkgconfig(libnl-route-3.0) >= 3.2.0
BuildRequires:	libcap-devel
%if 0%{?suse_version} >= 1220
BuildRequires:  systemd-rpm-macros
%endif
Patch0:		check_if_psr_ops_were_initialized.patch
Patch1:		start_teamd_from_usr_sbin.patch
Patch2:		ignore_ebusy_for_team_hwaddr_set.patch
Patch3:		add_dbus_policy_template.patch
Patch4:		cap_net_raw.patch

Patch5:		fix_member_port_state_change_on_team_up.patch

#
# Some defines
#
%define teamd_user			teamd
%define teamd_group			daemon
%define teamd_daemon_directory		/run/teamd
%define teamd_dbus_policy_directory	%_sysconfdir/dbus-1/system.d
%define teamd_dbus_policy_name		org.libteam.teamd.conf

%description
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n libteam5
Summary:        Library for controlling 802.1AX team network device
Group:          System/Libraries

%description -n libteam5
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n libteamdctl0
Summary:        Library for controlling the team network device daemon
Group:          System/Libraries

%description -n libteamdctl0
Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package devel
Summary:        Development files for libteam
Group:          Development/Libraries/C and C++
Requires:       libteam5 = %version
Requires:       libteamdctl0 = %version

%description devel
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

This package contains the development headers for the libteam and
libteamdctl libraries.

%package tools
Summary:        Utilities for controlling team network devices
Group:          System/Daemons

%description tools
This package contains frontends to libteam that allow changing
the (team-specific) properties of team devices.
(The general configuration of network devices can be done
through using iproute.)

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n python-libteam
Summary:        Python bindings for libteam
Group:          Development/Languages/Python

%description -n python-libteam
This package should be installed if you want to develop Python
programs that will manipulate team network devices.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%configure --includedir="%_includedir/pkg/%name" --bindir="%_sbindir" \
	--disable-static \
	--with-run-dir=%teamd_daemon_directory \
	--with-user=%teamd_user \
	--with-group=%teamd_group
# Use CFLAGS= to kill -Werror
make %{?_smp_mflags} CFLAGS="%optflags"

pushd binding/python/;
python ./setup.py build;
popd;

%install
b="%buildroot";
make install DESTDIR="$b";
pushd binding/python/;
python ./setup.py install --root="$b" --prefix="%_prefix";
popd;

rm -f "$b/%_libdir"/*.la
%if 0%{?_unitdir:1}
mkdir -p "$b/%_unitdir";
install -pm0644 teamd/redhat/systemd/*.service "$b/%_unitdir/";
%endif

%if 0%{?_sysconfdir:1}
mkdir -p "$b/%teamd_dbus_policy_directory/";
install -pm0644 teamd/dbus/teamd.conf "$b/%teamd_dbus_policy_directory/%teamd_dbus_policy_name";
%endif

%check
make check

%pre tools
%{_sbindir}/groupadd -r %teamd_group 2> /dev/null || :
%{_sbindir}/useradd -r -g %teamd_group -s /bin/false -c "Teamd daemon user" -d %{_localstatedir}/lib/empty %teamd_user 2> /dev/null || :
%{_sbindir}/usermod -g %teamd_group %teamd_user 2>/dev/null || :
test -L %teamd_daemon_directory  || rm -rf %teamd_daemon_directory && :
%if 0%{?_unitdir:1}
%service_add_pre teamd@.service
%endif

%post tools
# reload dbus to apply new teamd's policy
/usr/bin/systemctl reload dbus.service 2>/dev/null || :
%if 0%{?_unitdir:1}
%service_add_post teamd@.service
%endif

%preun tools
%if 0%{?_unitdir:1}
%service_del_preun teamd@.service
%endif

%postun tools
%if 0%{?_unitdir:1}
%service_del_postun teamd@.service
%endif
# reload dbus to forget teamd's policy
if [ ${FIRST_ARG:-$1} -eq 0 ]; then
        /usr/bin/systemctl reload dbus.service 2>/dev/null || :
fi

%post   -n libteam5 -p /sbin/ldconfig
%postun -n libteam5 -p /sbin/ldconfig
%post   -n libteamdctl0 -p /sbin/ldconfig
%postun -n libteamdctl0 -p /sbin/ldconfig

%files -n libteam5
%defattr(-,root,root)
%_libdir/libteam.so.5*

%files -n libteamdctl0
%defattr(-,root,root)
%_libdir/libteamdctl.so.0*

%files devel
%defattr(-,root,root)
%_includedir/pkg/
%_libdir/libteam.so
%_libdir/libteamdctl.so
%_libdir/pkgconfig/libteam*.pc

%files tools
%defattr(-,root,root)
%_sbindir/bond2team
%_sbindir/team*
%dir %_sysconfdir/dbus-1
%dir %teamd_dbus_policy_directory
%config %teamd_dbus_policy_directory/%teamd_dbus_policy_name
%_mandir/man1/*
%_mandir/man5/*
%_mandir/man8/*
%if 0%{?_unitdir:1}
%_unitdir
%endif

%files -n python-libteam
%defattr(-,root,root)
%python_sitearch/*

%changelog
* Wed Oct 14 2015 pwieczorkiewicz@suse.com
- Add fix_member_port_state_change_on_team_up.patch:
  * Upstream fix for incorrect member ports' state change to CURRENT
  when team device is brought UP, while partner is still DOWN.
* Tue Oct  6 2015 pwieczorkiewicz@suse.com
- Add cap_net_raw.patch:
  * CAP_NET_RAW capability is needed for packet sockets creation.
* Mon Oct  5 2015 pwieczorkiewicz@suse.com
- Update to new upstream release 1.21:
  * libteam: check for definition of NLA_PUT_S* separately
  * libteam: add missing "static inline" in nl_updates
* Mon Oct  5 2015 pwieczorkiewicz@suse.com
- Update to new upstream release 1.20:
  * libteam: fix compile error with newer libnl
* Mon Oct  5 2015 pwieczorkiewicz@suse.com
- Update to new upstream release 1.19:
  * Remove patches that went upstream:
  - add_missing_prototypes_for_admin_state_functions.patch
  - dont_fail_on_missing_port.patch
  - drop_privileges_to_teamd_user.patch
  - libteam_teamd_Track_admin_state_of_team_device.patch
  - libteamdctl_fix_timeval_value_for_select.patch
  - reduce_usock_file_permissions_to_700.patch
  - teamd_lacp_Don_t_send_LACP_frames_when_master_team.patch
  - teamd_loadbalance_mode_lacks_a_.hwaddr_changed.patch
  * teamd: fix delay_up mistaken rename to queue_id
  * teamd: lacp: update actor state before sending LACP frames
  * teamd: add Before=network.target to systemd service file
- Fix teamd deamon directory to /run/teamd (bsc#947542)
- Fix teamd user directory to /var/lib/empty
- Handle dbus policy file under tools package
- Reload DBus daemon after tools package (un)installation in order
  to (un)apply new policy (bsc#947542)
- Add add_dbus_policy_template.patch
* Fri Sep 25 2015 pwieczorkiewicz@suse.com
- Do not call useradd command adding new 'teamd' user with an -o
  option (bsc#947542)
* Mon Sep 14 2015 pwieczorkiewicz@suse.com
- Fix drop_privileges_to_teamd_user.patch:
  * Fix correct ncap value for cap_set_flag function call.
  * Add corrected teamd.conf.in dbus policy template
* Fri Sep 11 2015 pwieczorkiewicz@suse.com
- Add drop_privileges_to_teamd_user.patch:
  * Daemon instances will run with UID specified in spec file and the
  daemon system group.
* Wed Sep  9 2015 pwieczorkiewicz@suse.com
- Update dont_fail_on_missing_port.patch:
  * Refreshed to the version accepted by upstream.
- Add upstream patches for upcoming release 1.19:
  * reduce_usock_file_permissions_to_700.patch
  * add_missing_prototypes_for_admin_state_functions.patch
  * libteam_teamd_Track_admin_state_of_team_device.patch
  * libteamdctl_fix_timeval_value_for_select.patch
  * teamd_lacp_Don_t_send_LACP_frames_when_master_team.patch
  * teamd_loadbalance_mode_lacks_a_.hwaddr_changed.patch
* Wed Sep  9 2015 pwieczorkiewicz@suse.com
- Update to new upstream release 1.18
  * Check to disallow creating device names longer than 15 chars.
  * Fix teamd memory corruption issues.
  * Fix sending duplicate LACP frames at the start of establishing a
  logical channel.
  * lacp: change actor system value on team mac change
* Thu Aug 27 2015 pwieczorkiewicz@suse.com
- Remove no_dbus_enabled_in_service_file.patch:
  * Apply default libteam's dbus policy config and enable DBus in
  service file by default. (bsc#941993)
- Remove add_org_libteam_teamd_conf.patch:
  * No need for own dbus policy file, since default can be used.
  (bsc#941993)
- Add libteam-rpmlintrc:
  * Lower badness of the following warnings:
    - dbus-policy-deny-without-destination
  - dbus-policy-allow-without-destination
    It is not possible to specify send_destination for teamd
    instances. For more details refer to (bsc#941993).
* Thu Aug 27 2015 pwieczorkiewicz@suse.com
- Remove no_dbus_enabled_in_service_file.patch:
  * Apply default libteam's dbus policy config and enable DBus in
  service file by default. (bsc#941993)
- Remove add_org_libteam_teamd_conf.patch:
  * No need for own dbus policy file, since default can be used.
  (bsc#941993)
- Add libteam-rpmlintrc:
  * Lower badness of the following warnings:
  - suse-dbus-unauthorized-service
    To be fixed by (bsc#941993)
    - dbus-policy-deny-without-destination
  - dbus-policy-allow-without-destination
    It is not possible to specify send_destination for teamd
    instances. For more details refer to (bsc#941993).
* Wed Aug 19 2015 pwieczorkiewicz@suse.com
- Add add_org_libteam_teamd_conf.patch:
  * Handle dbus policy file separately from the upstream. For now dbus
  policy is not enabled by default. In order to manually enable it
  please refer to README.SUSE. (bsc#941993)
- Add dont_fail_on_missing_port.patch:
  * Do not fail completely when a port specified in config is missing.
- Add start_teamd_from_usr_sbin.patch:
  * Modify service file to start teamd instance from /usr/sbin.
- Add check_if_psr_ops_were_initialized.patch:
  * Fix teamd segfault when link_watch initialization callbacks fail
  (e.g. lw_psr_port_added() in case of activebackup runner) due to
  an attempt to change hwaddr on an enslaved, link up port device.
  Note: enslavement triggers initialization callbacks.
- Add no_dbus_enabled_in_service_file.patch:
  Disable DBus interface by default for now in teamd service file.
- Add ignore_ebusy_for_team_hwaddr_set.patch:
  * Make PortAdd and PortRemove dbus methods work for all runners.
  Ignore attempts to change hwaddr of an already enslaved devices.
  (fate#318389,fate#317728,fate#316923)
* Fri Jul 31 2015 jengelh@inai.de
- Update to new upstream release 1.17
  * teamd: lw: nsna_ping: fix NA RX and ARP RX handling
  * libteam: ifinfo: fix rtnl dellink handling
* Fri Jul 31 2015 pwieczorkiewicz@suse.com
- Initial libteam 1.16 version submission to SLE-12 SP1
  (fate#318389,fate#317728,fate#316923)
* Sun Mar 29 2015 jengelh@inai.de
- Update to new upstream release 1.16
  * teamdctl: show port link down count in state output
  * teamd: lw: count how many times has been the port down
* Thu Jan  8 2015 jengelh@inai.de
- Update to new upstream release 1.15
  * Topology-aware failover with TIPC
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 1.11
  * add support for TIPC link watcher
  * teamd quits when the device is removed
  * teamd: add support for checking multiple ports IFLA_PHYS_PORT_ID
* Thu Aug  8 2013 jengelh@inai.de
- Update to new upstream release 1.5
  * lacp: introduce multiple aggregator selection policies
  * lacp: allow to have multiple functions to find out which port
  is better
  * lacp: introduce agg select policy based on per-port config
  options
  * teamd: introduce simple SR-IOV support
  * lacp: do not set state disable if driver does not report speed
  and duplex
  * teamd: add support for multicast group rejoin sending
  * utils: add bond2team conversion tool
* Thu Feb 28 2013 jengelh@inai.de
- Update to new upstream release 1.0 -
  (no changes summary provided; this is the first tarball release)
* Wed Nov 14 2012 jengelh@inai.de
- Update to git snapshot 0+git368 [a62cd9309607c6d72d46ef68403a730a6367b827] -
  no changes summary provided by upstream
- Install systemd service file for teamd
- Build and install python bindings
* Sat May 12 2012 jengelh@inai.de
- Initial package for build.opensuse.org
